#
# spec file for package log4j
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with extras
Name:           log4j
Version:        2.13.0
Release:        4.3.1
Summary:        Java logging package
License:        Apache-2.0
URL:            http://logging.apache.org/%{name}
Source0:        http://archive.apache.org/dist/logging/%{name}/%{version}/apache-%{name}-%{version}-src.tar.gz
Source1:        http://archive.apache.org/dist/logging/%{name}/%{version}/apache-%{name}-%{version}-src.tar.gz.asc
Patch1:         logging-log4j-LOG4J2-2745-LOG4J2-2744-slf4j.patch
Patch2:         logging-log4j-Remove-unsupported-EventDataConverter.patch
#PATCH-FIX-UPSTREAM bsc#1170535 CVE-2020-9488: Improper validation of certificate with host mismatch in SMTP appender
Patch3:         log4j-CVE-2020-9488.patch
Patch4:         CVE-2021-44228.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core)
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind)
BuildRequires:  mvn(com.lmax:disruptor)
BuildRequires:  mvn(com.sun.mail:javax.mail)
BuildRequires:  mvn(org.apache.commons:commons-compress)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.logging:logging-parent:pom:)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.fusesource.jansi:jansi)
BuildRequires:  mvn(org.jctools:jctools-core)
BuildRequires:  mvn(org.osgi:osgi.core)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-ext)
Obsoletes:      log4j-mini
BuildArch:      noarch
%if %{with extras}
BuildRequires:  mvn(com.datastax.cassandra:cassandra-driver-core)
BuildRequires:  mvn(com.fasterxml.jackson.dataformat:jackson-dataformat-xml)
BuildRequires:  mvn(com.fasterxml.jackson.dataformat:jackson-dataformat-yaml)
BuildRequires:  mvn(com.fasterxml.woodstox:woodstox-core)
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(javax.servlet.jsp:jsp-api)
BuildRequires:  mvn(javax.servlet:javax.servlet-api)
BuildRequires:  mvn(org.apache.commons:commons-csv)
BuildRequires:  mvn(org.apache.tomcat:tomcat-catalina)
BuildRequires:  mvn(org.eclipse.jetty:jetty-util)
BuildRequires:  mvn(org.eclipse.persistence:javax.persistence)
BuildRequires:  mvn(org.jboss.spec.javax.jms:jboss-jms-api_1.1_spec)
BuildRequires:  mvn(org.lightcouch:lightcouch)
BuildRequires:  mvn(org.zeromq:jeromq)
BuildRequires:  mvn(sun.jdk:jconsole)
# Explicit requires for javapackages-tools since log4j-jmx script
# uses /usr/share/java-utils/java-functions
Requires:       javapackages-tools
%endif

%description
Log4j is a tool to help the programmer output log statements to a
variety of output targets.

%package slf4j
Summary:        Binding between LOG4J 2 API and SLF4J

%description slf4j
Binding between LOG4J 2 API and SLF4J.

%package jcl
Summary:        Apache Log4j Commons Logging Bridge

%description jcl
Apache Log4j Commons Logging Bridge.

%if %{with extras}
%package osgi
Summary:        Apache Log4J Core OSGi Bundles

%description osgi
Apache Log4J Core OSGi Bundles.

%package taglib
Summary:        Apache Log4j Tag Library

%description taglib
Apache Log4j Tag Library for Web Applications.

%package jmx-gui
Summary:        Apache Log4j JMX GUI
Requires:       java-devel

%description jmx-gui
Swing-based client for remotely editing the log4j configuration and remotely
monitoring StatusLogger output. Includes a JConsole plug-in.

%package web
Summary:        Apache Log4j Web

%description web
Support for Log4j in a web servlet container.

%package bom
Summary:        Apache Log4j BOM

%description bom
Apache Log4j 2 Bill of Material

%package nosql
Summary:        Apache Log4j NoSql

%description nosql
Use NoSQL databases such as MongoDB and CouchDB to append log messages.

%endif

%package        javadoc
Summary:        API documentation for %{name}
Obsoletes:      %{name}-manual < %{version}

%description    javadoc
%{summary}.

%prep
%setup -q -n apache-%{name}-%{version}-src
%autopatch -p1

%pom_remove_plugin -r :maven-site-plugin
%pom_remove_plugin -r :maven-remote-resources-plugin
%pom_remove_plugin -r :maven-doap-plugin
%pom_remove_plugin -r :maven-source-plugin
%pom_remove_plugin -r :maven-toolchains-plugin
%pom_remove_plugin -r :revapi-maven-plugin

# remove all the stuff we'll build ourselves
find -name "*.jar" -o -name "*.class" -delete
rm -rf docs/api

%pom_disable_module %{name}-distribution
%pom_disable_module %{name}-samples

# Apache Flume is not in openSUSE yet
%pom_disable_module %{name}-flume-ng

# artifact for upstream testing of log4j itself, shouldn't be distributed
%pom_disable_module %{name}-perf

# needs java 9 to build
%pom_disable_module %{name}-api-java9
%pom_disable_module %{name}-core-java9
%pom_remove_dep -r :%{name}-api-java9
%pom_remove_dep -r :%{name}-core-java9
%pom_remove_plugin -r :maven-dependency-plugin

# unavailable com.conversantmedia:disruptor
rm log4j-core/src/main/java/org/apache/logging/log4j/core/async/DisruptorBlockingQueueFactory.java
%pom_remove_dep -r com.conversantmedia:disruptor

# kafka not available
rm -r log4j-core/src/main/java/org/apache/logging/log4j/core/appender/mom/kafka
%pom_remove_dep -r :kafka-clients

# liquibase not available
%pom_disable_module %{name}-liquibase

# we don't have slf4j 1.8 yet
%pom_disable_module %{name}-slf4j18-impl

# we don't have commons-dbcp2
%pom_disable_module %{name}-jdbc-dbcp2

# We have mongodb 4
%pom_disable_module %{name}-mongodb2
%pom_disable_module %{name}-mongodb3

# System scoped dep provided by JDK
%pom_remove_dep :jconsole %{name}-jmx-gui
%pom_add_dep sun.jdk:jconsole %{name}-jmx-gui

# old AID is provided by felix, we want osgi-core
%pom_change_dep -r org.osgi:org.osgi.core org.osgi:osgi.core

# BOM package shouldn't require Apache RAT
%pom_remove_plugin :apache-rat-plugin %{name}-bom

# tests are disabled
%pom_remove_plugin :maven-failsafe-plugin

%if %{without extras}
%pom_disable_module %{name}-taglib
%pom_disable_module %{name}-jmx-gui
%pom_disable_module %{name}-bom
%pom_disable_module %{name}-web
%pom_disable_module %{name}-iostreams
%pom_disable_module %{name}-jul
%pom_disable_module %{name}-core-its
%pom_disable_module %{name}-jpa
%pom_disable_module %{name}-couchdb
%pom_disable_module %{name}-cassandra
%pom_disable_module %{name}-appserver
%pom_disable_module %{name}-spring-cloud-config
%pom_disable_module %{name}-kubernetes

%pom_remove_dep -r :jackson-dataformat-yaml
%pom_remove_dep -r :jackson-dataformat-xml
%pom_remove_dep -r :woodstox-core
%pom_remove_dep -r :javax.persistence
%pom_remove_dep -r :jboss-jms-api_1.1_spec
%pom_remove_dep -r :jeromq
%pom_remove_dep -r :commons-csv

rm -r log4j-core/src/main/java/org/apache/logging/log4j/core/{jackson,config/yaml,parser}
rm -r log4j-core/src/main/java/org/apache/logging/log4j/core/appender/{db,mom,nosql}
rm log4j-core/src/main/java/org/apache/logging/log4j/core/layout/*{Csv,Jackson,Xml,Yaml,Json,Gelf}*.java
rm log4j-1.2-api/src/main/java/org/apache/log4j/builders/layout/*Xml*.java
rm log4j-api/src/main/java/org/apache/logging/log4j/util/Activator.java
rm -r log4j-1.2-api/src/main/java/org/apache/log4j/or/jms
%endif

%{mvn_alias} :%{name}-1.2-api %{name}:%{name}

# Note that packages using the compatibility layer still need to have log4j-core
# on the classpath to run. This is there to prevent build-classpath from putting
# whole dir on the classpath which results in loading incorrect provider
%{mvn_file} ':{%{name}-1.2-api}' %{name}/@1 %{name}

%{mvn_package} ':%{name}-slf4j-impl' slf4j
%{mvn_package} ':%{name}-to-slf4j' slf4j
%{mvn_package} ':%{name}-taglib' taglib
%{mvn_package} ':%{name}-jcl' jcl
%{mvn_package} ':%{name}-jmx-gui' jmx-gui
%{mvn_package} ':%{name}-web' web
%{mvn_package} ':%{name}-bom' bom
%{mvn_package} ':%{name}-cassandra' nosql
%{mvn_package} ':%{name}-couchdb' nosql

%{mvn_package} :log4j-core-its __noinstall

%build
# missing test deps (mockejb)
%{mvn_build} -f -- -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%if %{with extras}
%jpackage_script org.apache.logging.log4j.jmx.gui.ClientGUI '' '' %{name}/%{name}-jmx-gui:%{name}/%{name}-core %{name}-jmx false
%endif

%files -f .mfiles
%dir %{_javadir}/%{name}
%license LICENSE.txt
%doc NOTICE.txt

%files slf4j -f .mfiles-slf4j

%files jcl -f .mfiles-jcl

%if %{with extras}
%files taglib -f .mfiles-taglib

%files web -f .mfiles-web

%files bom -f .mfiles-bom

%files nosql -f .mfiles-nosql

%files jmx-gui -f .mfiles-jmx-gui
%{_bindir}/%{name}-jmx
%endif

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt
%doc NOTICE.txt

%changelog
* Fri Dec 10 2021 psimons@suse.com
- Apply "CVE-2021-44228.patch" to fix a remote code execution
  vulnerability that existed in the LDAP JNDI parser. [bsc#1193611,
  CVE-2021-44228]
* Mon Apr 27 2020 pmonrealgonzalez@suse.com
- Security fix: [bsc#1170535, CVE-2020-9488]
  * Improper validation of certificate with host mismatch in SMTP appender.
- Add log4j-CVE-2020-9488.patch
* Wed Feb 26 2020 fstrba@suse.com
- Added patches:
  * logging-log4j-LOG4J2-2745-LOG4J2-2744-slf4j.patch
  * logging-log4j-Remove-unsupported-EventDataConverter.patch
    + fix build with newer slf4j
* Tue Jan 21 2020 pmonrealgonzalez@suse.com
- Update to 2.13.0 [bsc#1159646, CVE-2019-17571]
  * Bugfixes and minor enhancements:
  - CVE-2019-17571: Remote code execution: Deserialization of untrusted
    data in SocketServer
  - Log4j 2 now requires Java 8 or higher to build and run.
  - Better integration with Spring Boot by providing access to Spring
    variables in Log4j 2 configuration files and allowing Log4j 2 system
    properties to be defined in the Spring configuration.
  - Support for accessing Kubernetes information via a Log4j 2 Lookup.
  - The Gelf Layout now allows the message to be formatted using a
    PatternLayout pattern.
  - Due to a break in compatibility in the SLF4J binding, Log4j now
    ships with two versions of the SLF4J to Log4j adapters.
  - log4j-slf4j-impl should be used with SLF4J 1.7.x and earlier and
    log4j-slf4j18-impl should be used with SLF4J 1.8.x and later.
  - Note that the XML, JSON and YAML formats changed in the 2.11.0 release:
    they no longer have the "timeMillis" attribute and instead have an
    "Instant" element with "epochSecond" and "nanoOfSecond" attributes.
  - The Log4j 2.13.0 API, as well as many core components, maintains
    binary compatibility with previous releases.
  * New Features
  - Add ThreadContext.putIfNotNull method.
  - Add a Level Patttern Selector.
  - Add experimental support for Log4j 1 configuration files.
  - Add the ability to lookup Kubernetes attributes in the Log4j
    configuration. Allow Log4j properties to be retrieved from the
    Spring environment if it is available.
  - Allow Spring Boot application properties to be accessed in the
    Log4j 2 configuration. Add lower and upper case Lookups.
  - Add builder pattern to Logger interface.
  * Fixed Bugs
  - Prevent recursive calls to java.util.LogManager.getLogger().
  - Added try/finally around event.execute() for RingBufferLogEventHandler
    to clear memory correctly in case of exception/error.
  - Wrong java version check in ThreadNameCachingStrategy.
  - Use a less confusing name for the CompositeConfiguration source.
  - Add setKey method to Kafka Appender Builder.
  - ArrayIndexOutOfBoundsException could occur with MAC address longer
    than 6 bytes.
  - The rolling file appenders would fail to compress the file after
    rollover if the file name matched the file pattern.
  - @PluginValue does not support attribute names besides "value".
  - Validation blocks definition of script in properties configuration.
  - Set result of rename action to true if file was copied.
  - Add automatic module names where missing.
  - OutputStreamAppender.Builder ignores setFilter().
  - Prevent a memory leak when async loggers throw errors.
  * Changes
  - Update Jackson to 2.9.10.
  - Allow message portion of GELF layout to be formatted using a PatternLayout.
  - Allow ThreadContext attributes to be explicitly included or excluded in the GelfLayout.
* Mon Jan  6 2020 fstrba@suse.com
- Obsolete log4j-mini, since on systems where this package is
  installed, the log4j-mini is not supposed to exist, but the
  compatibility version log4j12-mini/log4j12
* Mon Nov  4 2019 fstrba@suse.com
- Run fdupes on the javadoc
* Tue Oct  1 2019 fstrba@suse.com
- Upgrade to apache-log4j-2.11.1
- Drop the log4j vs. log4j-mini split
  * the bootstrapping is done using the log4j12/log4j12-mini
    compatibility packages
- Removed patches:
  * log4j-javadoc-xlink.patch
  * log4j-logfactor5-userdir.patch
  * log4j-mx4j-tools.patch
  * log4j-reproducible.patch
    + unnecessary with this version
* Tue Jan 22 2019 fstrba@suse.com
- Build against a generic javamail provider instead of against
  classpathx-mail
* Tue Jan 15 2019 fstrba@suse.com
- Let log4j provide the log4j-mini and obsolete it too.
- Remove conflicts on each other
* Thu Dec 13 2018 fstrba@suse.com
- Depend on the generic xml-apis
* Thu Oct 18 2018 fstrba@suse.com
- Install and package the maven pom and metadata files for the
  non-bootstrap log4j
* Wed Jul 25 2018 fstrba@suse.com
- Require at least java 8 for build
* Wed Jan 10 2018 bwiedemann@suse.com
- Add log4j-reproducible.patch to drop javadoc timestamps to make
  package builds more reproducible (boo#1047218)
* Tue Sep 12 2017 fstrba@suse.com
- Specify java source and target level 1.6 to allow building with
  jdk9
* Mon Mar  2 2015 tchvatal@suse.com
- Version bump to 1.2.17 latest 1.2 series:
  * No short changelog provided - many small changes
- Try to avoid cycle between log4j and apache-common-loggings
- Remove obsoleted patch:
  * log4j-jmx-Agent.patch
- Refresh patch to apply to new source:
  * log4j-mx4j-tools.patch
* Mon Mar  2 2015 tchvatal@suse.com
- Cleanup with a spec-cleaner so I can understand what
  is going around here.
* Thu Sep 12 2013 mvyskocil@suse.com
- log4j and log4j-mini are in conflict
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Jul 16 2013 mls@suse.de
- get rid of wrong dir modifier in filelist
* Thu Dec 10 2009 mvyskocil@suse.cz
- refreshed patches
  * log4j-javadoc-xlink.patch
  * log4j-jmx-Agent.patch
  * log4j-logfactor5-userdir.patch
  * log4j-mx4j-tools.patch
* Wed Jul 16 2008 coolo@suse.de
- even more packages to build ignore
* Fri Jun 27 2008 coolo@suse.de
- avoid build cycle between axis and log4j
* Tue May  6 2008 mvyskocil@suse.cz
- removed a dots in a names of geronimo-* packages
* Tue Apr  8 2008 mvyskocil@suse.cz
- updated to 1.2.5 [bnc#355798]
- merged a spec with jpackage 1.7
  - the ant arguments was splitted to several lines
  - new BuildRequires:
  - classpathx-javamail
  - geronimo-jaf
  - geronimo-jms
  - a new patches to break of a dependendy on Sun's HtmlAdaptorServer
    (replaced by HttpAdaptor from mx4j package)
  - added a gjc build branch
- created an autogenerated -mini specfile used for bootstrap (hint from sbrabec@suse.cz)
  - added an explicit provides of log4j symbol for log4j-mini (automatically by script)
- replaced a name `macro' by `real', because the -mini package has a different name
- disable the javadoc and manual subpackages for -mini build
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Fri May 18 2007 dbornkessel@suse.de
- removed mx4j BuildReq to avoid build cycle ... apparently it was not used at compile time
* Tue May  8 2007 dbornkessel@suse.de
- use mx4j instead of jmx
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 jsmeix@suse.de
- Current version 1.2.12 from JPackage.org
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Nov 25 2004 ro@suse.de
- added suse_update_desktop_file
* Thu Sep 23 2004 mskibbe@suse.de
- change specfile(suse_update_desktop_file)
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires for javadoc subpackage.
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 1.2.8 (JPackage 1.5)
